@@ -12,45 +12,45 @@ data(churn)
 str(churn)
 
 ## -----------------------------------------------------------------------------
-set.seed(5)
+set.seed(42)
 
 data_sets = partition(data = churn, ratio = c(0.8, 0.2))
 
-train_set = data_sets $ part1
-test_set  = data_sets $ part2
+train_set = data_sets$part1
+test_set  = data_sets$part2
 
-actual_test  = test_set $ churn
+test_labels  = test_set$churn
 
 ## -----------------------------------------------------------------------------
 formula = churn ~ account.length + voice.plan + voice.messages + intl.plan + intl.mins + 
                   day.mins + eve.mins + night.mins + customer.calls
 
-predict_knn = kNN(formula, train = train_set, test = test_set, k = 8)
+predict_knn = kNN(formula, train = train_set, test = test_set, k = 6)
 
 ## ----fig.align = 'center', fig.height = 3, fig.width = 3----------------------
-conf.mat(predict_knn, actual_test)
+conf.mat(predict_knn, test_labels)
 
-conf.mat.plot(predict_knn, actual_test)
+conf.mat.plot(predict_knn, test_labels)
 
 ## -----------------------------------------------------------------------------
-mse(predict_knn, actual_test)
+mse(predict_knn, test_labels)
 
 ## -----------------------------------------------------------------------------
-predict_knn_trans = kNN(formula, train = train_set, test = test_set, k = 8, scaler = "minmax")
+predict_knn_trans = kNN(formula, train = train_set, test = test_set, k = 6, scaler = "minmax")
 
 ## ----fig.show = "hold", fig.align = 'default', out.width = "46%"--------------
-conf.mat.plot(predict_knn_trans, actual_test)
+conf.mat.plot(predict_knn_trans, test_labels)
 
-conf.mat.plot(predict_knn, actual_test)
+conf.mat.plot(predict_knn, test_labels)
 
 ## -----------------------------------------------------------------------------
-prob_knn = kNN(formula, train = train_set, test = test_set, k = 8, type = "prob")[ , 1 ]
+prob_knn = kNN(formula, train = train_set, test = test_set, k = 6, type = "prob")[, 1]
 
-prob_knn_trans = kNN(formula, train = train_set, test = test_set, scaler = "minmax", k = 8, type = "prob")[ , 1 ]
+prob_knn_trans = kNN(formula, train = train_set, test = test_set, scaler = "minmax", k = 6, type = "prob")[, 1]
 
 ## ----message = F, fig.align = "center"----------------------------------------
-roc_knn = roc(actual_test, prob_knn)
-roc_knn_trans = roc(actual_test, prob_knn_trans)
+roc_knn = roc(test_labels, prob_knn)
+roc_knn_trans = roc(test_labels, prob_knn_trans)
 
 ggroc(list(roc_knn, roc_knn_trans), size = 0.8) + 
     theme_minimal() + ggtitle("ROC plots with AUC") +
